<?php

namespace Drupal\private_message\Mapper;

use Drupal\user\UserInterface;

interface PrivateMessageMapperInterface {

  /**
   * Retrieve the ID of a thread from the database, 
   * which contains all of the given UIDs, and only
   * the given UIDs.
   *
   * @param array $uids
   *   An array of User IDs of users whose thread should be
   *   retrieved.
   *
   * @return int|bool
   *   If a thread is found, the thread ID will be returned. Otherwise
   *   FALSE will be returned.
   */
  public function getThreadIdForMembers(array $uids);

  /**
   * Retrieve the ID of the most recently updated thread for
   * the given user
   *
   * @param \Drupal\user\UserInterface $user
   *   The user whose most recently updated thread should be retrieved
   *
   * @return int|bool
   *   The ID of the most recently updated thread the user is a member of
   *   if one exists, or FALSE if one doesn't
   */
  public function getFirstThreadIdForUser(UserInterface $user);

  /**
   * Retrieve a list of thread IDs for threads the user belongs to
   *
   * @param \Drupal\user\UserInterface $user
   *   The user whose most recently thread IDs should be retrieved
   * @param int $count
   *   The number of thread IDs to retrieve
   * @param int $timestamp
   *   A timestamp relative to which only thread IDs with an earlier timestamp should be returned
   *
   * @return array
   *   An array of thread IDs if any threads exist
   */ 
  public function getThreadIdsForUser(UserInterface $user, $count, $id = FALSE);

  /**
   * Check if a thread exists after the given thread ID
   *
   * @param \Drupal\user\UserInterface $user
   *   The user for whom to check
   * @param int $timestamp
   *   The timestamp to check against
   *
   * @return bool
   *   TRUE if a previous thread exists, FALSE if one doesn't.
   */
  public function checkForNextThread(UserInterface $user, $timestamp);

  /**
   * Get a list of account IDs whose account names begin with the given string.
   * Only accounts that have 'Use private messaging system' permission will be
   * returned, and the viewing user must have both 'View user information' and
   * 'access user profiles' to get any results at all.
   *
   * @param string $string
   *   The string to search for
   * @param int $count
   *   The number of results to return
   *
   * @return int[]
   *   An array of account IDs for accounts whose account names begin
   *   with the given string.
   */
  public function getUserIdsFromString($string, $count);
}
