<?php

namespace Drupal\private_message\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldWidget\EntityReferenceAutocompleteWidget;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * A widget bar.
 *
 * @FieldWidget(
 *   id = "private_message_thread_member_widget",
 *   label = @Translation("Private message members autocomplete"),
 *   field_types = {
 *     "entity_reference"
 *   },
 * )
 */
class PrivateMessageThreadMemberWidget extends EntityReferenceAutocompleteWidget {

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    return $field_definition->getFieldStorageDefinition()->getTargetEntityTypeId() == 'private_message_thread' && $field_definition->getFieldStorageDefinition()->getSetting('target_type') == 'user';
  }

  /**
   * {@inheritdoc}
   *
   * The settings summary is returned empty, as the parent settings have no
   * effect on this form
   */
  public function settingsSummary() {
    $summary = parent::settingsSummary();

    unset($summary[0]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   *
   * No form should be shown, as this override has no custom settings
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    unset($form['match_operator']);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

	$element['#attached']['library'][] = 'private_message/members_widget';
	$url = Url::fromRoute('private_message.members_widget_callback');
    $token = \Drupal::csrfToken()->get($url->getInternalPath());
    $url->setOptions(['absolute' => TRUE, 'query' => ['token' => $token]]);

	$element['#attached']['drupalSettings']['privateMessageMembersWidget']['callbackPath'] = $url->toString();
    $element['#attached']['drupalSettings']['privateMessageMembersWidget']['placeholder'] = $this->getSetting('placeholder');
    $element['#attached']['drupalSettings']['privateMessageMembersWidget']['fieldSize'] = $this->getSetting('size');

    return $element;
  }
}
